@@ -3,7 +3,6 @@ from datetime import datetime
 from django.db import models
 from django.db.models.signals import post_save
 from django.core.urlresolvers import reverse
-from django.utils.html import escape
 from django.utils.translation import ugettext_lazy as _
 
 from django.contrib.auth.models import User
@@ -108,7 +107,7 @@ def tweet(sender, instance, created, **kwargs):
             pass # oh well
         else:
             if notification:
-                notification.send([reply_recipient], "tweet_reply_received", {'tweet': tweet,})
+                notification.send([reply_recipient], "tweet_reply_received", {'tweet': instance,})
     
     # now send to all the recipients
     for recipient in recipients:
